# Autotab Python API Library

The Autotab Python library provides convenient access to the Autotab REST API from any Python 3.7+ application. 

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

## Installation

```sh
pip install autotab-ai
```

## Usage

```python

import autotab
from autotab import RunSkillRequest
from autotab.rest import ApiException
from pprint import pprint


client = autotab.Client(
    autotab.Configuration(
        api_key = os.environ["AUTOTAB_API_KEY"]
    )
)

try:
    run = await autotab.RunApi(client).start(
        run_skill_request=RunSkillRequest(
            skill_id="skill_a6738f77-afc2-454e-a6d6-207caa8d145f",
            inputs={
                "query": "OpenAI news"
            }
        )
    )
    run = await autotab.RunApi(client).retrieve(
        id=run.id
    )
    print(f"new run:\n{run.model_dump_json(indent=2)}")
    
    await asyncio.sleep(20)
    
    run = await autotab.RunApi(client).retrieve(
        id=run.id
    )
    print(f"state: {run.state} output: {run.data}")
    
except ApiException as e:
    print(f"Exception: {e})

```

## Documentation for API Endpoints

All URIs are relative to *https://api.autotab.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*RunApi* | [**cancel**](docs/RunApi.md#cancel) | **POST** /run/{id}/cancel | Cancel
*RunApi* | [**list_runs**](docs/RunApi.md#list_runs) | **GET** /run/list | List
*RunApi* | [**retrieve_run**](docs/RunApi.md#retrieve_run) | **GET** /run/{id} | Retrieve
*RunApi* | [**start**](docs/RunApi.md#start) | **POST** /run/ | Start
*RunApi* | [**video_url**](docs/RunApi.md#video_url) | **GET** /run/{id}/video_url | Video Url
*SkillApi* | [**list_skills**](docs/SkillApi.md#list_skills) | **GET** /skill/list | List
*SkillApi* | [**retrieve_skill**](docs/SkillApi.md#retrieve_skill) | **GET** /skill/{id} | Retrieve


## Documentation For Models

 - [Environment](docs/Environment.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Input](docs/Input.md)
 - [RunSession](docs/RunSession.md)
 - [RunSessionState](docs/RunSessionState.md)
 - [RunSkillRequest](docs/RunSkillRequest.md)
 - [Skill](docs/Skill.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [VariableDataType](docs/VariableDataType.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="HTTPBearer"></a>
### HTTPBearer

- **Type**: Bearer authentication
